@@ -10,6 +10,9 @@
 #ifndef VERSION_H
 #define VERSION_H
 
-#define KMYFIREWALL_VERSION "0.9.6.2"
-
+#define KMYFIREWALL_VERSION "1.0"
+#define COPYRIGHT_DATE "(c) 2002-2005"
+#define COPYRIGHT_OWNER "The KMyFirewall Team"
+#define COPYRIGHT_STRING "copyright (c) the KMyFirewall developers 2002-2005"
+#define MAINTAINER "Christian Hubinger <chubinegr@sedisys.com>"
 #endif
